@@ -42,6 +42,7 @@ async def _read_stdout(stdout):
                 response = json.loads(str(decoded_bytes, "utf-8"))
                 await response_function(response.get("Message", "Response does not contain Message."), response)
             elif b"Caching task done." in response:
+                print('stdout: ' + response.decode('utf-8'))
                 await response_function("Caching task done.", {})
             else:
                 print('stdout: ' + response.decode('utf-8'))
@@ -147,6 +148,18 @@ async def query_slapp(query: str):
     if n:
         options.add("--queryIsRegex")
 
+    insensitive_query_is_clantag = re.compile(re.escape('--queryisclantag'), re.IGNORECASE)
+    (query, n) = insensitive_query_is_clantag.subn('', query)
+    query = query.strip()
+    if n:
+        options.add("--queryIsClanTag")
+
+    insensitive_clantag = re.compile(re.escape('--clantag'), re.IGNORECASE)
+    (query, n) = insensitive_clantag.subn('', query)
+    query = query.strip()
+    if n:
+        options.add("--queryIsClanTag")
+
     print(f"Posting {query=} to existing Slapp process with options {' '.join(options)} ...")
     await slapp_write_queue.put('--b64 ' + str(base64.b64encode(query.encode("utf-8")), "utf-8") + ' ' +
                                 ' '.join(options))
